<?php

namespace Keywordrush\AffiliateEgg;

defined('\ABSPATH') || exit;

/**
 * ExtractorConfig class file
 *
 * @author keywordrush.com <support@keywordrush.com>
 * @link https://www.keywordrush.com
 * @copyright Copyright &copy; 2024 keywordrush.com
 */
class ExtractorConfig extends Config
{

    public function page_slug()
    {
        return 'affiliate-egg-extractor-settings';
    }

    public function option_name()
    {
        return 'affegg_extractor';
    }

    public function add_admin_menu()
    {
        \add_submenu_page('options.php', __('Extractor settings', 'affegg') . ' &lsaquo; Affiliate Egg', __('Proxy settings', 'affegg'), 'manage_options', $this->page_slug, array($this, 'settings_page'));
    }

    protected function options()
    {
        $options = array(
            'scrapingdog_token' => array(
                'title' => __('Scrapingdog API key', 'affegg'),
                'description' => sprintf(__('Your <a target="_blanl" href="%s">Scrapingdog</a> token.', 'affegg'), 'https://www.keywordrush.com/go/scrapingdog'),
                'callback' => array($this, 'render_input'),
                'default' => '',
                'validator' => array(
                    'trim',
                ),
            ),
            'scrapingdog_domains' => array(
                'title' => __('Scrapingdog whitelist domains', 'affegg'),
                'description' => sprintf(__('Comma-separated list of domains should send requests through the %s service.', 'affegg'), 'scrapingdog'),
                'callback' => array($this, 'render_input'),
                'default' => '',
                'validator' => array(
                    array(
                        'call' => array($this, 'proxyDomainsFilter'),
                        'type' => 'filter',
                    ),
                ),
            ),

            'scrapeowl_token' => array(
                'title' => __('Scrapeowl API key', 'affegg'),
                'description' => __('Your Scrapeowl.com token.', 'affegg'),
                'callback' => array($this, 'render_input'),
                'default' => '',
                'validator' => array(
                    'trim',
                ),
            ),
            'scrapeowl_domains' => array(
                'title' => __('Scrapeowl whitelist domains', 'affegg'),
                'description' => sprintf(__('Comma-separated list of domains should send requests through the %s service.', 'affegg'), 'scrapingdog'),
                'callback' => array($this, 'render_input'),
                'default' => '',
                'validator' => array(
                    array(
                        'call' => array($this, 'proxyDomainsFilter'),
                        'type' => 'filter',
                    ),
                ),
            ),

            'scraperapi_token' => array(
                'title' => __('Scraperapi API key', 'affegg'),
                'description' => sprintf(__('Your <a target="_blanl" href="%s">Scraperapi</a> token.', 'affegg'), 'https://www.keywordrush.com/go/scraperapi'),
                'callback' => array($this, 'render_input'),
                'default' => '',
                'validator' => array(
                    'trim',
                ),
            ),
            'scraperapi_domains' => array(
                'title' => __('Scraperapi whitelist domains', 'affegg'),
                'description' => sprintf(__('Comma-separated list of domains should send requests through the %s service.', 'affegg'), 'scraperapi'),
                'callback' => array($this, 'render_input'),
                'default' => '',
                'validator' => array(
                    array(
                        'call' => array($this, 'proxyDomainsFilter'),
                        'type' => 'filter',
                    ),
                ),
            ),
            'proxycrawl_token' => array(
                'title' => __('Crawlbase token', 'affegg'),
                'description' => __('Your Crawlbase.com token.', 'affegg'),
                'callback' => array($this, 'render_input'),
                'default' => '',
                'validator' => array(
                    'trim',
                ),
            ),
            'proxycrawl_domains' => array(
                'title' => __('Crawlbase whitelist domains', 'affegg'),
                'description' => sprintf(__('Comma-separated list of domains should send requests through the Crawlbase service.', 'affegg'), 'proxycrawl'),
                'callback' => array($this, 'render_input'),
                'default' => '',
                'validator' => array(
                    array(
                        'call' => array($this, 'proxyDomainsFilter'),
                        'type' => 'filter',
                    ),
                ),
            ),

            'direct_request' => array(
                'title' => __('Direct request', 'affegg'),
                'description' => __('Make the first attempt without using scrapping services.', 'affegg'),
                'callback' => array($this, 'render_dropdown'),
                'dropdown_options' => array(
                    'enabled' => __('Enabled', 'affegg'),
                    'disabled' => __('Disabled', 'affegg'),
                ),
                'default' => 'disabled',
            ),
            'retry_attempts' => array(
                'title' => __('Retry attempts', 'affegg'),
                'description' => __('The maximum number of retries when failed request. Must be between 0 to 5.', 'affegg'),
                'callback' => array($this, 'render_input'),
                'default' => '0',
                'validator' => array(
                    'trim',
                    'abs',
                    array(
                        'call' => array('\Keywordrush\AffiliateEgg\FormValidator', 'less_than_equal_to'),
                        'arg' => 5,
                        'message' => sprintf(__('The field "%s" can not be more than %d.', 'affegg'), 'Retry attempts', 5),
                    ),
                ),
            ),
        );

        return $options;
    }

    public function settings_page()
    {
        AffiliateEggAdmin::getInstance()->render('settings', array('page_slug' => $this->page_slug()));
    }

    public function proxyDomainsFilter($value)
    {
        $domains = TextHelper::commaListArray($value);
        $results = array();
        foreach ($domains as $domain)
        {
            if ($h = TextHelper::getHostName($domain))
                $host = $h;
            else
                $host = preg_replace('/^www\./', '', strtolower(trim(\sanitize_text_field($domain))));

            if ($host && TextHelper::isValidDomainName($host))
                $results[] = $host;
        }
        $results = array_unique($results);
        return join(',', $results);
    }
}
