<?php

namespace Keywordrush\AffiliateEgg;

defined('\ABSPATH') || exit;

/**
 * TikivnParser class file
 *
 * @author keywordrush.com <support@keywordrush.com>
 * @link https://www.keywordrush.com
 * @copyright Copyright &copy; 2024 keywordrush.com
 */
class TikivnParser extends MicrodataShopParser
{

    protected $charset = 'utf-8';
    protected $currency = 'VND';

    public function parseCatalog($max)
    {
        if (preg_match_all('/"url_path":"([^"]+)","availability"/', $this->dom->saveHtml(), $matches))
            $urls = $matches[1];
        else
            $urls = array();

        if (!$urls)
        {
            $path = array(
                ".//a[@class='product-item']/@href",
                ".//div[contains(@class, 'product-item')]//a/@href",
                ".//*[@class='search-a-product-item']",
                ".//p[@class='title']/a/@href",
            );

            $urls = $this->xpathArray($path);
        }

        foreach ($urls as $i => $url)
        {
            $urls[$i] = strtok($url, '?');
        }

        return $urls;
    }

    public function parseTitle()
    {
        if ($p = parent::parseTitle())
            return $p;
        else
            return $this->xpathScalar(".//h1");
    }

    public function parsePrice()
    {
        if ($p = parent::parsePrice())
            return $p;

        $path = array(
            ".//div[@class='product-price__current-price']",
        );
        return $this->xpathScalar($path);
    }

    public function parseDescription()
    {

        $path = array(
            ".//div[@class='content']//div[contains(@class, 'ToggleContent__Wrapper-sc')]",
            ".//div[@class='summary']//div[@class='group border-top']",
        );
        return $this->xpathScalar($path, true);
    }

    public function parseImg()
    {
        return str_replace('/280x280/', '/368x368/', parent::parseImg());
    }

    public function parseOldPrice()
    {
        if (preg_match('/,"list_price":(\d+),"/', $this->dom->saveHTML(), $matches))
            return $matches[1];

        $paths = array(
            ".//div[@class='summary']//p[@class='original-price']",
        );

        if ($price = $this->xpathScalar($paths))
            return $price;
    }

    public function getFeaturesXpath()
    {
        return array(
            array(
                'name' => ".//div[contains(@class, 'ProductDescription__Wrapper')]//table//tr/td[1]",
                'value' => ".//div[contains(@class, 'ProductDescription__Wrapper')]//table//tr/td[2]",
            ),
            array(
                'name' => ".//div[contains(@class, 'style__Wrapper')]//table//tr/td[1]",
                'value' => ".//div[contains(@class, 'style__Wrapper')]//table//tr/td[2]",
            ),
        );
    }
}
